@@ -14,7 +14,10 @@ static const char distr_name[] = "gig";
 #define eta    params[2]    
 #define DISTR distr->data.cont
 static double _unur_pdf_gig( double x, const UNUR_DISTR *distr );
+static double _unur_logpdf_gig( double x, const UNUR_DISTR *distr );
 static double _unur_dpdf_gig( double x, const UNUR_DISTR *distr );
+static double _unur_dlogpdf_gig( double x, const UNUR_DISTR *distr );
+static int _unur_upd_mode_gig( UNUR_DISTR *distr );
 static int _unur_set_params_gig( UNUR_DISTR *distr, const double *params, int n_params );
 double
 _unur_pdf_gig(double x, const UNUR_DISTR *distr)
@@ -25,6 +28,14 @@ _unur_pdf_gig(double x, const UNUR_DISTR *distr)
   return (exp( (theta-1.) * log(x) - 0.5 * omega * (x/eta + eta/x) ));
 } 
 double
+_unur_logpdf_gig(double x, const UNUR_DISTR *distr)
+{ 
+  register const double *params = DISTR.params;
+  if (x <= 0.)
+    return -INFINITY;
+  return ( (theta-1.) * log(x) - 0.5 * omega * (x/eta + eta/x) );
+} 
+double
 _unur_dpdf_gig(double x, const UNUR_DISTR *distr)
 { 
   register const double *params = DISTR.params;
@@ -33,6 +44,26 @@ _unur_dpdf_gig(double x, const UNUR_DISTR *distr)
   return ( exp( (theta-3.) * log(x) - 0.5 * omega * (x/eta + eta/x) )
 	   * (eta*eta*omega + 2.*eta*(theta-1.)*x - omega*x*x) / (2*eta) );
 } 
+double
+_unur_dlogpdf_gig(double x, const UNUR_DISTR *distr)
+{ 
+  register const double *params = DISTR.params;
+  if (x <= 0.)
+    return 0.;
+  return ( -0.5*(omega*(1/eta - eta/(x*x))) + (theta-1.)/x );
+} 
+int
+_unur_upd_mode_gig( UNUR_DISTR *distr )
+{
+  register const double *params = DISTR.params;
+  DISTR.mode =
+    (eta*(-1. + sqrt(omega*omega + (theta-1.)*(theta-1.)) + theta))/omega;
+  if (DISTR.mode < DISTR.domain[0]) 
+    DISTR.mode = DISTR.domain[0];
+  else if (DISTR.mode > DISTR.domain[1]) 
+    DISTR.mode = DISTR.domain[1];
+  return UNUR_SUCCESS;
+} 
 int
 _unur_set_params_gig( UNUR_DISTR *distr, const double *params, int n_params )
 {
@@ -71,17 +102,24 @@ unur_distr_gig( const double *params, int n_params )
   distr->id = UNUR_DISTR_GIG;
   distr->name = distr_name;
   DISTR.init = _unur_stdgen_gig_init;
-  DISTR.pdf  = _unur_pdf_gig;   
-  DISTR.dpdf = _unur_dpdf_gig;  
-  DISTR.cdf  = NULL;            
+  DISTR.pdf     = _unur_pdf_gig;     
+  DISTR.logpdf  = _unur_logpdf_gig;  
+  DISTR.dpdf    = _unur_dpdf_gig;    
+  DISTR.dlogpdf = _unur_dlogpdf_gig; 
+  DISTR.cdf  = NULL;                 
   distr->set = ( UNUR_DISTR_SET_DOMAIN |
-		 UNUR_DISTR_SET_STDDOMAIN );
+		 UNUR_DISTR_SET_STDDOMAIN |
+		 UNUR_DISTR_SET_MODE   );
   if (_unur_set_params_gig(distr,params,n_params)!=UNUR_SUCCESS) {
     free(distr);
     return NULL;
   }
+  _unur_upd_mode_gig(distr);
   DISTR.set_params = _unur_set_params_gig;
+  DISTR.upd_mode  = _unur_upd_mode_gig; 
   return distr;
 } 
-#undef nu
+#undef theta
+#undef omega
+#undef eta
 #undef DISTR
