@@ -14,7 +14,11 @@ UNUR_DISTR *unur_distr_extremeI(const double *params, int n_params);
 UNUR_DISTR *unur_distr_extremeII(const double *params, int n_params);
 UNUR_DISTR *unur_distr_F(const double *params, int n_params);
 UNUR_DISTR *unur_distr_gamma(const double *params, int n_params);
+UNUR_DISTR *unur_distr_ghyp(const double *params, int n_params);
 UNUR_DISTR *unur_distr_gig(const double *params, int n_params);
+UNUR_DISTR *unur_distr_gig2(const double *params, int n_params);
+UNUR_DISTR *unur_distr_hyperbolic(const double *params, int n_params);
+UNUR_DISTR *unur_distr_ig(const double *params, int n_params);
 UNUR_DISTR *unur_distr_laplace(const double *params, int n_params);
 UNUR_DISTR *unur_distr_logistic(const double *params, int n_params);
 UNUR_DISTR *unur_distr_lognormal(const double *params, int n_params);
