@@ -1,4 +1,4 @@
-/* Copyright (c) 2000-2008 Wolfgang Hoermann and Josef Leydold */
+/* Copyright (c) 2000-2009 Wolfgang Hoermann and Josef Leydold */
 /* Department of Statistics and Mathematics, WU Wien, Austria  */
 
 struct unur_dstd_par { 
@@ -9,8 +9,8 @@ struct unur_dstd_gen {
   int     n_gen_param;    
   int    *gen_iparam;     
   int     n_gen_iparam;   
-  double  umin;           
-  double  umax;           
+  double  Umin;           
+  double  Umax;           
   int  is_inversion;           
   const char *sample_routine_name; 
 };
