@@ -15,6 +15,7 @@
 #include "cstd.h"
 #include "hinv.h"
 #include "ninv.h"
+#include "pinv.h"
 #include "mvstd.h"
 #include "norta.h"
 #include "norta_struct.h"
@@ -333,6 +334,9 @@ _unur_norta_make_marginalgen( const struct unur_gen *gen,
     else {
       _unur_par_free(par);
     }
+    par = unur_pinv_new( marginal );
+    if ( (marginalgen = _unur_init(par)) != NULL )
+      break;
     par = unur_hinv_new( marginal );
     if ( (marginalgen = _unur_init(par)) != NULL )
       break;
